@@ -1,6 +1,6 @@
 #!/bin/sh
 ##
-##    (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
+##    (C) Copyright 2002-2022 Fred Gleason <fredg@paravelsystems.com>
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of version 2.1 of the GNU Lesser General Public
@@ -17,6 +17,15 @@
 ##    Boston, MA  02111-1307  USA
 ##
 
+#
+# Generate Debian packaging metadata
+#
+DATESTAMP=`date +%a,\ %d\ %b\ %Y\ %T\ %z`
+sed s/@VERSION@/`cat PACKAGE_VERSION`/ < debian/control.src > debian/control
+sed s/@VERSION@/`cat PACKAGE_VERSION`/ < debian/changelog.src | sed "s/@DATESTAMP@/$DATESTAMP/" > debian/changelog
+
+mkdir -p m4
+
 libtoolize=libtoolize
 if which glibtoolize > /dev/null 2>&1; then
       libtoolize=glibtoolize
